//
//  Scilab ( http://www.scilab.org/ ) - This file is part of Scilab
//  Copyright (C) 2012 - Pawel Zagorski
//
//  This file must be used under the terms of the CeCILL.
//  This source file is licensed as described in the file COPYING, which
//  you should have received as part of this distribution.  The terms
//  are also available at
//  http://www.cecill.info/licences/Licence_CeCILL_V2-en.txt


function block=AB_plot_groundtrack(block,flag)

block_name = "AB_plot_groundtrack";
xcos_block_debug(block, flag, block_name);

select flag
  case 1 then
  // Output computation
    vec = block.inptr(1);
    if ~and(vec == zeros(3,1)) then
      win_id = findobj("Tag", block.label);
      win_id.user_data = [win_id.user_data vec];
      [color_id traj_color_id thickness traj_thickness steps area res coord]=get_parameters(block);
      %CL_rad2deg = 180/%pi; //defining myself because it is faster
      //CL_init();
      CL_plot_ephem(win_id.user_data, win_id, traj_color_id, steps, ..
        area, traj_thickness);
    else
      time = getscicosvars("t0");
      if time <> 0 then
        warning(msprintf("\t%s : Encountered empty input vector at time = %f!\n", block_name, time));
      end
    end
  case 4 then
  // Initialization
    AB_check_param_number(block_name, block, 5, 1, 0);
    // Figure needs to be created or reused before any color() call to 
    // avoid creating empty graphic window
    win_id = findobj("Tag", block.label);
    if win_id == [] then
      win_id = figure("Tag", block.label,'Figure_name', ..
        'Groundtrack plot');
      win_id.background = color("white");
    end         
    [color_id traj_color_id thickness traj_thickness steps area res coord]=get_parameters(block);
    axes_id = win_id.children;
    axes_id.x_label.text = "longitude [degrees]";
    axes_id.y_label.text = "latitude [degrees]";
    CL_plot_earthMap(win_id,color_id,steps,area,thickness,res,coord);
  case 5 then
  // Ending
    win_id = findobj("Tag", block.label);
    win_id.user_data = [];
  case 6 then
  // Initialization, fixed-point computation
    ;
  else
    error(msprintf(gettext("%s : Incorect flag %d"), block_name, flag));
end

endfunction


function [color_id, traj_color_id, thickness, traj_thickness, steps, area, res, coord]=get_parameters(block)

    thickness = block.ipar(1);
    traj_thickness = block.ipar(2);
    color_id = block.ipar(3);
    traj_color_id = block.ipar(4);
    steps = block.opar(1);
    area = block.opar(2); 
    res = block.opar(3); 
    coord = block.opar(4);

endfunction
