//
//  Scilab ( http://www.scilab.org/ ) - This file is part of Scilab
//  Copyright (C) 2012 - Pawel Zagorski
//
//  This file must be used under the terms of the CeCILL.
//  This source file is licensed as described in the file COPYING, which
//  you should have received as part of this distribution.  The terms
//  are also available at
//  http://www.cecill.info/licences/Licence_CeCILL_V2-en.txt


function block=AB_timeframe_conversion(block,flag)

block_name = "AB_timeframe_conversion";
block_label = "TIMEFRAME_CONVERSION";
xcos_block_debug(block, flag, block_name);

select flag
  case 1 then
  // Output computation
    timeframe_from = block.opar(1);
    timeframe_to = block.opar(2);
    value_from = block.inptr(1);
    if (timeframe_from == "cjd") then
      select timeframe_to
	case "cal"
	  [year,month,day,hour,minute,sec] = CL_dat_cjd2cal(value_from);
	  block.outptr(1) = [year;month;day;hour;minute;sec];
	case "mjd"
	  block.outptr(1) = CL_dat_cjd2mjd(value_from);
	case "jd"
	  block.outptr(1) = CL_dat_cjd2jd(value_from);
	else
	  error(msprintf("Incorrect timeframe to convert to: %s",..
                timeframe_to));
      end
    elseif (timeframe_from == "jd") then
      select timeframe_to
	case "cal"
	  [year,month,day,hour,minute,sec] = CL_dat_jd2cal(value_from);
	  block.outptr(1) = [year;month;day;hour;minute;sec];
	case "mjd"
          cjd = CL_dat_jd2cjd(value_from);
	  block.outptr(1) = CL_dat_cjd2mjd(cjd);
	case "cjd"
	  block.outptr(1) = CL_dat_jd2cjd(value_from);
	else
	  error(msprintf("Incorrect timeframe to convert to: %s",..
                timeframe_to));
      end
    elseif (timeframe_from == "mjd") then
      select timeframe_to
	case "cal"
	  cjd = CL_dat_mjd2cjd(value_from);
	  [year,month,day,hour,minute,sec] = CL_dat_cjd2cal(cjd);
	  block.outptr(1) = [year;month;day;hour;minute;sec];
	case "jd"
          cjd = CL_dat_mjd2cjd(value_from);
	  block.outptr(1) = CL_dat_cjd2jd(cjd);
	case "cjd"
	  block.outptr(1) = CL_dat_mjd2cjd(value_from);
	else
	  error(msprintf("Incorrect timeframe to convert to: %s",..
                timeframe_to));
      end
    elseif (timeframe_from == "cal") then
      // check input correctness
      time = getscicosvars("t0");
      err = AB_check_cal_date(value_from, time, block_label);
      if err < 0 then
 	set_blockerror(err);
      elseif err > 0 then
        // go for it
        select timeframe_to
	  case "mjd"
	    cjd = CL_dat_cal2cjd(value_from);
	    block.outptr(1) = CL_dat_cjd2mjd(cjd);
	  case "jd"
            block.outptr(1) = CL_dat_cal2jd(value_from);
	  case "cjd"
	    block.outptr(1) = CL_dat_cal2cjd(value_from);
	  else
	    error(msprintf("Incorrect timeframe to convert to: %s",..
                  timeframe_to));
        end
      end
    else
	error(msprintf("Conversion from this time frame is not implemented yet: %s", timeframe_from));
    end
  case 4 then
  // Initialization
    AB_check_param_number(block_name, block, 0, 1, 0);
    timeframe_from = block.opar(1);
    timeframe_to = block.opar(2);
    if and(timeframe_from <> ["cal" "mjd" "jd" "cjd"]) then
      error(msprintf(gettext("\t%s : Incorrect value of model.opar(1)\n"),..
      block_name)); 
    end
    if and(timeframe_from <> ["cal" "mjd" "jd" "cjd"]) then
      error(msprintf(gettext("\t%s : Incorrect value of model.opar(2)\n"),..
      block_name));
    end
    if timeframe_from == timeframe_to then
      error(msprintf(gettext("\t%s : Conversion between the same time frames\n"),..
      block_name)); 
    end
  case 5 then
  // Ending
    ;
  case 6 then
  // Initialization, fixed-point computation
    ;
  else
    error(msprintf(gettext("%s : Incorect flag %d"), block_name, flag));
end

endfunction
