// This file is released under the 3-clause BSD license. See COPYING-BSD.
//=================================

// Test flags
//<-- XCOS TEST -->
//<-- NO CHECK ERROR OUTPUT -->

//Load xcos test diagram for US76_atm_model tests
[macros,path] = libraryinfo('xcos_aerolib');
result = importXcosDiagram(path + "../tests/unit_tests" + "/atmUS76.xcos");
assert_checktrue(result);

//This diagram uses 2 variables : 
//  altitude : altitude (from_workspace)
//  pressure : pressure (to_workspace)
//  temperature : temperature (to_workspace)
//  density : density (to_workspace)

scicos_simulate(scs_m);

// Define expected values
exp_time = [0.1; 1.1; 2.1; 3.1; 4.1; 5.1; 6.1; 7.1; 8.1; 9.1];
exp_pressure = [1.01325000e+05; 3.20127846e-02; 8.47349055e-05; 8.77030533e-06; 1.45174065e-06; 3.02384600e-07; 8.21245563e-08; 3.19136017e-08; 1.70351702e-08; 1.08728757e-08]; 
exp_temperature = [288.15; 195.08134; 854.55909; 976.0078; 995.82536; 999.2356; 999.85303; 999.97039; 999.99376;999.99863];
exp_density = [1.22499916e+00; 5.60439369e-07; 2.54068762e-10; 1.91575177e-11; 2.80259592e-12; 5.21585048e-13; 1.13666107e-13; 3.06979130e-14; 1.13578362e-14; 5.75898819e-15];

//Validate results
assert_checkequal(temperature.time, exp_time);
assert_checkalmostequal(temperature.values, exp_temperature, 1e-4);
assert_checkequal(pressure.time, exp_time);
assert_checkalmostequal(pressure.values, exp_pressure, 1e-4);
assert_checkequal(density.time, exp_time);
assert_checkalmostequal(density.values, exp_density, 1e-4);
