// This file is released under the 3-clause BSD license. See COPYING-BSD.
//=================================


// Test flags
//<-- XCOS TEST -->
//<-- NO CHECK ERROR OUTPUT -->

//Load xcos test diagram for g50_to_ter tests
[macros,path] = libraryinfo('xcos_aerolib');
result = importXcosDiagram(path + "../tests/unit_tests" +"/g50_to_ter.xcos");
assert_checktrue(result);

//This diagram uses 4 variables : 
//  pos_in  : position input vectors
//  vel_in  : velocity input vectors
//  pos_out : cartesian position output vectors (to_workspace)
//  vel_out : cartesian velocity output vectors (to_workspace)

pos_in = [[3500.e3;2500.e3;5800.e3] , [4500.e3;2100.e3;6800.e3]];
vel_in = [[1.e3;3.e3;7.e3] , [2.e3;3.e3;6.e3]];
scicos_simulate(scs_m);

// Define expected values
exp_time = [0.3; 0.6; 0.9]; 
exp_pos(:,:,1) =  [ - 4267561.6,  - 4957376.;   
                    - 536579.97,    290557.35;  
                      5800000.,     6800000.];
exp_pos(:,:,2) =  [   830221.53,    1832093.5;  
                      4220276.3,    4615564.3;  
                      5800000.,     6800000.];
exp_pos(:,:,3) =  [   3746313.8,    3807111.;   
                    - 2113086.2,  - 3188401.8; 
                      5800000.,     6800000.]; 
exp_vel(:,:,1) =  [ - 2344.5625,  - 3164.134;   
                    - 1853.2841,  - 1327.7996;  
                      7000.,        6000.];
exp_vel(:,:,2) =  [ - 1023.5917,  - 267.39031;  
                      2807.8275,    3421.0084;  
                      7000.,        6000.];
exp_vel(:,:,3) =  [   2987.2162,    3332.0129;  
                      90.412439,  - 820.05264;  
                      7000.,        6000.];

//Validate results
assert_checkalmostequal(exp_time, pos_out.time, 1e-8);
assert_checkalmostequal(exp_time, vel_out.time, 1e-8);
assert_checkalmostequal(exp_pos(:,:,1), pos_out.values(:,:,1),1e-6);
assert_checkalmostequal(exp_pos(:,:,2), pos_out.values(:,:,2),1e-6);
assert_checkalmostequal(exp_pos(:,:,3), pos_out.values(:,:,3),1e-6);
assert_checkalmostequal(exp_vel(:,:,1), vel_out.values(:,:,1),1e-6);
assert_checkalmostequal(exp_vel(:,:,2), vel_out.values(:,:,2),1e-6);
assert_checkalmostequal(exp_vel(:,:,3), vel_out.values(:,:,3),1e-6);

